@@ -6,6 +6,7 @@
 # Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
@@ -31,3 +32,7 @@ class InvalidReporterError(Exception):
 
 class InvalidArgsError(ValueError):
     """raised when passed arguments are invalid, e.g., have the wrong length"""
+
+
+class NoLineSuppliedError(Exception):
+    """raised when trying to disable a message on a next line without supplying a line number"""
