@@ -1,30 +1,22 @@
-# copyright 2003-2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
-#
-# This file is part of pylint.
-#
-# pylint is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, either version 2.1 of the License, or (at your option) any
-# later version.
-#
-# pylint is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
-# details.
-#
-# You should have received a copy of the GNU Lesser General Public License along
-# with pylint.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2015-2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
+# Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
+# Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
+# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+
+# Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+
 """Micro reports objects.
 
 A micro report is a tree of layout and content objects.
 """
 
-from six import string_types
-
-
-class VNode(object):
 
+class VNode:
     def __init__(self, nid=None):
         self.id = nid
         # navigation
@@ -51,16 +43,18 @@ class VNode(object):
         visitor
         """
         try:
-            return self.TYPE.replace('-', '_')
+            # pylint: disable=no-member
+            return self.TYPE.replace("-", "_")
+        # pylint: disable=broad-except
         except Exception:
             return self.__class__.__name__.lower()
 
     def accept(self, visitor, *args, **kwargs):
-        func = getattr(visitor, 'visit_%s' % self._get_visit_name())
+        func = getattr(visitor, "visit_%s" % self._get_visit_name())
         return func(self, *args, **kwargs)
 
     def leave(self, visitor, *args, **kwargs):
-        func = getattr(visitor, 'leave_%s' % self._get_visit_name())
+        func = getattr(visitor, "leave_%s" % self._get_visit_name())
         return func(self, *args, **kwargs)
 
 
@@ -70,8 +64,9 @@ class BaseLayout(VNode):
     attributes
     * children : components in this table (i.e. the table's cells)
     """
+
     def __init__(self, children=(), **kwargs):
-        super(BaseLayout, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         for child in children:
             if isinstance(child, VNode):
                 self.append(child)
@@ -97,17 +92,19 @@ class BaseLayout(VNode):
 
 # non container nodes #########################################################
 
+
 class Text(VNode):
     """a text portion
 
     attributes :
     * data : the text value as an encoded or unicode string
     """
+
     def __init__(self, data, escaped=True, **kwargs):
-        super(Text, self).__init__(**kwargs)
-        #if isinstance(data, unicode):
+        super().__init__(**kwargs)
+        # if isinstance(data, unicode):
         #    data = data.encode('ascii')
-        assert isinstance(data, string_types), data.__class__
+        assert isinstance(data, str), data.__class__
         self.escaped = escaped
         self.data = data
 
@@ -119,8 +116,10 @@ class VerbatimText(Text):
     * data : the text value as an encoded or unicode string
     """
 
+
 # container nodes #############################################################
 
+
 class Section(BaseLayout):
     """a section
 
@@ -132,14 +131,27 @@ class Section(BaseLayout):
     a description may also be given to the constructor, it'll be added
     as a first paragraph
     """
+
     def __init__(self, title=None, description=None, **kwargs):
-        super(Section, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         if description:
             self.insert(0, Paragraph([Text(description)]))
         if title:
             self.insert(0, Title(children=(title,)))
 
 
+class EvaluationSection(Section):
+    def __init__(self, message, **kwargs):
+        super().__init__(**kwargs)
+        title = Paragraph()
+        title.append(Text("-" * len(message)))
+        self.append(title)
+
+        message_body = Paragraph()
+        message_body.append(Text(message))
+        self.append(message_body)
+
+
 class Title(BaseLayout):
     """a title
 
@@ -170,10 +182,9 @@ class Table(BaseLayout):
     * cheaders : the first col's elements are table's header
     * title : the table's optional title
     """
-    def __init__(self, cols, title=None,
-                 rheaders=0, cheaders=0,
-                 **kwargs):
-        super(Table, self).__init__(**kwargs)
+
+    def __init__(self, cols, title=None, rheaders=0, cheaders=0, **kwargs):
+        super().__init__(**kwargs)
         assert isinstance(cols, int)
         self.cols = cols
         self.title = title
